@@ -5,7 +5,7 @@ Sys.unsetenv("R_TESTS")
 
 if(requireNamespace("rhdf5")){
   tpDir2 <- gsub("[\\]", "/", tpDir)
-  tptpDir <- paste0(tpDir2, "/tpDir")
+  tptpDir <- file.path(tpDir2, "/tpDir")
   
   dir.create(tptpDir)
   test_that("h5 : write more than one studies mono thread", {
@@ -13,15 +13,18 @@ if(requireNamespace("rhdf5")){
                    writeAllSimulations = TRUE, nbCores = 1, opts = optsG)
     
   })
-
-
-  test_that("h5 : overwrite + alldata + multi-thread", {
-    writeAntaresH5(path = tptpDir, overwrite = TRUE, allData = TRUE, 
-                   timeSteps = "annual", writeAllSimulations = TRUE, 
-                   nbCores = 2, opts = optsG)
-    
-  })
-
+  VV <- utils::sessionInfo()
+  DoPar <- as.numeric(paste0(VV$R.version$major, VV$R.version$minor))>34
+  
+  if(DoPar)
+  {
+    test_that("h5 : overwrite + alldata + multi-thread", {
+      writeAntaresH5(path = tptpDir, overwrite = TRUE, allData = TRUE, 
+                     timeSteps = "annual", writeAllSimulations = TRUE, 
+                     nbCores = 2, opts = optsG)
+      
+    })
+  }
   
   test_that("h5 : overwrite + removeVirtualAreas", {
     writeAntaresH5(path = tptpDir, overwrite = TRUE, opts = optsG, timeSteps = "hourly",removeVirtualAreas = TRUE,
