@@ -1,9 +1,13 @@
 #Copyright © 2016 RTE Réseau de transport d’électricité
 
 context("Function readInputTS")
-
+sapply(studyPathS, function(studyPath){
+  
 opts <- setSimulationPath(studyPath)
 
+
+if(!isH5Opts(opts)){
+
 test_that("Load importation works", {
   input <- readInputTS(load = "all", showProgress = FALSE)
   expect_is(input, "antaresDataTable")
@@ -73,3 +77,5 @@ test_that("Link capacity importation works", {
   expect_gt(nrow(input), 0)
   expect_equal(nrow(input) %% (24 * 7 * nweeks), 0)
 })
+}
+})
